darkhistory.electrons.ics.BE_integrals.F_inv_a — DarkHistory documentation

# darkhistory.electrons.ics.BE_integrals.F_inv_a

`darkhistory.electrons.ics.BE_integrals.` `F_inv_a`(lowlim, a, tol=1e-10)

  Integral of 1/((x+a)(exp(x) - 1)) from lowlim to infinity.

  Parameters: | a : ndarray Parameter in (x+a). lowlim : ndarray Lower limit of integration. tol : float The relative tolerance to be reached.
  Returns: | ndarray The resulting integral.

#### Previous topic

darkhistory.electrons.ics.BE_integrals.F_inv_5

#### Next topic

darkhistory.electrons.ics.BE_integrals.F_inv_n

### This Page

Show Source